!  this is for cosmos 
subroutine csetSmpTblconst
  implicit none

  call cmkTPXSconst
  call cmkDCSconst
end subroutine csetSmpTblconst


